| fetch_wine_reviews | R Documentation |
A data set containing data on wines from 44 countries, taken from Wine Enthusiast Magazine during the week of 15 June 2017. The data are downloaded and returned.
fetch_wine_reviews()
A data frame with 110,203 rows and 8 columns:
Country of origin
State or province of origin
Region of origin
Name of vineyard that made the wine
Variety of grape
Points allocated by WineEnthusiast reviewer on a scale of 0-100
Price of a bottle of wine in $US
Year of wine extracted from title
Data frame
Rob J Hyndman (2026) "That's weird: Anomaly detection using R", Section 1.4, https://OTexts.com/weird/.
## Not run:
wine_reviews <- fetch_wine_reviews()
wine_reviews |>
ggplot(aes(x = points, y = price)) +
geom_jitter(height = 0, width = 0.2, alpha = 0.1) +
scale_y_log10()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.