| oldfaithful | R Documentation |
A data set containing data on recorded eruptions of the Old Faithful Geyser in Yellowstone National Park, Wyoming, USA, from 14 January 2017 to 29 December 2023. Recordings are incomplete, especially during the winter months when observers may not be present.
oldfaithful
A data frame with 2097 rows and 4 columns:
Time eruption started
Duration of eruption as recorded
Duration of eruption in seconds
Time to the following eruption in seconds
Data frame
Rob J Hyndman (2026) "That's weird: Anomaly detection using R", Section 1.4, https://OTexts.com/weird/.
oldfaithful |>
ggplot(aes(x = duration, y = waiting)) +
geom_point()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.