Learn R Programming

weird (version 3.1.0)

gun_deaths: Gun ownership and homicide rates by country

Description

A data set containing gun ownership rates and homicide rates for 2017 for various countries around the world. The gun ownership rates are the number of guns owned by civilians per 100 people. The homicide rates are the number of homicides per 100,000 people where the weapon was a firearm.

Usage

gun_deaths

Arguments

Value

Data frame

Format

A data frame with 77 rows and 4 columns:

country

Country name

region

World region according to Our World in Data

gun_ownership_rate

Gun ownership rate (number of guns owned by civilians per 100 people)

homicide_rate

Homicide rate (number of homicides per 100,000 people where the weapon was a firearm)

Examples

Run this code
gun_deaths

Run the code above in your browser using DataLab