For a dist_kde object, determine which highest density region (HDR)
each observation falls in, for one or more coverage probabilities. Some
densities are multimodal, so the HDR for a given prob can consist of
several disjoint regions; the returned columns identify the specific
region (1, 2, ...) that each observation falls in, ordered from
lowest to highest along the first variable, with NA for observations
outside the HDR at that prob.