kde_bandwidth: Robust bandwidth estimation for kernel density estimation
Description
Bandwidth matrices are estimated in several ways including
a normal reference rule,
a robust version of the normal reference rule (default),
a plugin estimator,
or using the approach of Hyndman, Kandanaarachchi & Turner (2026).
Details of each method are given in Hyndman (2026).
A matrix of bandwidths (or a scalar in the case of univariate data).
Arguments
data
A numeric matrix or data frame.
method
A character string giving the method to use. Possibilities are:
"normal" (normal reference rule),
"robust" (a robust version of the normal reference rule, the default),
"plugin" (a plugin estimator), and
"lookout" (the bandwidth matrix estimate of Hyndman, Kandanaarachchi & Turner, 2026).