Compute stray scores indicating how anomalous each observation is.
Usage
stray_scores(y, ...)
Value
Numerical vector containing stray scores.
Arguments
y
A vector, matrix, or data frame consisting of numerical variables.
...
Other arguments are passed to find_HDoutliers.
Author
Rob J Hyndman
References
P D Talagala, R J Hyndman and K Smith-Miles (2021) Anomaly detection
in high-dimensional data, Journal of Computational and Graphical Statistics, 30(2), 360-374.